@@ -16,10 +16,12 @@
 output.
 """
 
+import sys
 import subprocess
 import re
 import threading
 import time
+import os
 try:
     import queue
 except ImportError:
@@ -27,6 +29,8 @@ except ImportError:
 
 from . import DecodeError
 
+COMMANDS = ('ffmpeg', 'avconv')
+
 
 class FFmpegError(DecodeError):
     pass
@@ -70,17 +74,73 @@ class QueueReaderThread(threading.Thread):
                 break
 
 
+def popen_multiple(commands, command_args, *args, **kwargs):
+    """Like `subprocess.Popen`, but can try multiple commands in case
+    some are not available.
+
+    `commands` is an iterable of command names and `command_args` are
+    the rest of the arguments that, when appended to the command name,
+    make up the full first argument to `subprocess.Popen`. The
+    other positional and keyword arguments are passed through.
+    """
+    for i, command in enumerate(commands):
+        cmd = [command] + command_args
+        try:
+            return subprocess.Popen(cmd, *args, **kwargs)
+        except OSError:
+            if i == len(commands) - 1:
+                # No more commands to try.
+                raise
+
+
+# For Windows error switch management, we need a lock to keep the mode
+# adjustment atomic.
+windows_error_mode_lock = threading.Lock()
+
+
 class FFmpegAudioFile(object):
     """An audio file decoded by the ffmpeg command-line utility."""
     def __init__(self, filename, block_size=4096):
-        try:
-            self.proc = subprocess.Popen(
-                ['ffmpeg', '-i', filename, '-f', 's16le', '-'],
-                stdout=subprocess.PIPE, stderr=subprocess.PIPE
+        # On Windows, we need to disable the subprocess's crash dialog
+        # in case it dies. Passing SEM_NOGPFAULTERRORBOX to SetErrorMode
+        # disables this behavior.
+        windows = sys.platform.startswith("win")
+        if windows:
+            windows_error_mode_lock.acquire()
+            SEM_NOGPFAULTERRORBOX = 0x0002
+            import ctypes
+            # We call SetErrorMode in two steps to avoid overriding
+            # existing error mode.
+            previous_error_mode = \
+                ctypes.windll.kernel32.SetErrorMode(SEM_NOGPFAULTERRORBOX)
+            ctypes.windll.kernel32.SetErrorMode(
+                previous_error_mode | SEM_NOGPFAULTERRORBOX
             )
+
+        try:
+            self.devnull = open(os.devnull)
+            self.proc = popen_multiple(
+                COMMANDS,
+                ['-i', filename, '-f', 's16le', '-'],
+                stdout=subprocess.PIPE,
+                stderr=subprocess.PIPE,
+                stdin=self.devnull,
+            )
+
         except OSError:
             raise NotInstalledError()
 
+        finally:
+            # Reset previous error mode on Windows. (We can change this
+            # back now because the flag was inherited by the subprocess;
+            # we don't need to keep it set in the parent process.)
+            if windows:
+                try:
+                    import ctypes
+                    ctypes.windll.kernel32.SetErrorMode(previous_error_mode)
+                finally:
+                    windows_error_mode_lock.release()
+
         # Start another thread to consume the standard output of the
         # process, which contains raw audio data.
         self.stdout_reader = QueueReaderThread(self.proc.stdout, block_size)
@@ -202,6 +262,7 @@ class FFmpegAudioFile(object):
         if hasattr(self, 'proc') and self.proc.returncode is None:
             self.proc.kill()
             self.proc.wait()
+            self.devnull.close()
 
     def __del__(self):
         self.close()
